<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Repositories\BanksRepository;
use Illuminate\Http\Request;

class BanksController extends Controller
{
    private $banksRepository;

    public function __construct(BanksRepository $banksRepository)
    {

        $this->banksRepository = $banksRepository;
    }

    public function index()
    {
        $rows = $this->banksRepository->index();
        return view('admin.banks.index', compact('rows'));
    }

    public function create()
    {
        return view('admin.banks.create');
    }

    public function store(Request $request)
    {
        $this->validate($request, [
            'bank_name_ar' => 'required',
            'bank_name_en' => 'required',
            'bank_image' => 'required|image',
            'iban_number' => 'required',
            'account_number' => 'required'
        ]);
        $this->banksRepository->store();
        success_toast();
        return redirect()->route('banks.index');
    }

    public function edit($id)
    {
        $row = $this->banksRepository->show($id);
        return view('admin.banks.edit', compact('row'));
    }

    public function update($id, Request $request)
    {
        $this->validate($request, [
            'bank_name_ar' => 'required',
            'bank_name_en' => 'required',
            'bank_image' => 'image',
            'iban_number' => 'required',
            'account_number' => 'required'
        ]);
        $this->banksRepository->update($id);
        success_toast();
        return redirect()->route('banks.index');
    }

    public function destory($id)
    {
        $this->banksRepository->destroy($id);
        success_toast();
        return redirect()->route('banks.index');
    }
}
