<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Repositories\CommonQuestionsRepository;
use Illuminate\Http\Request;

class CommonQuestionsController extends Controller
{

    private $commonQuestions;

    public function __construct(CommonQuestionsRepository $commonQuestions)
    {
        $this->commonQuestions = $commonQuestions;
    }

    public function index()
    {
        $rows = $this->commonQuestions->index();
        return view('admin.common_questions.index', compact('rows'));
    }

    public function create()
    {
        return view('admin.common_questions.create');
    }

    public function store(Request $request)
    {
        $this->validate($request, [
            'name' => 'required',
            'email' => 'required|email',
            'question' => 'required',
            'answer' => 'required',
            'show' => 'required|in:true,false'

        ]);
        $this->commonQuestions->store();

        success_toast();
        return redirect()->route('common_questions.index');

    }


    public function show($id)
    {
        //
    }

    public function edit($id)
    {
        $row = $this->commonQuestions->show($id);
        return view('admin.common_questions.edit', compact('row'));
    }


    public function update(Request $request, $id)
    {

        $this->validate($request, [
            'name' => 'required',
            'email' => 'required|email',
            'question' => 'required',
            'answer' => 'required',
            'show' => 'required|in:true,false'
        ]);

        $this->commonQuestions->update($id);

        success_toast();
        return redirect()->route('common_questions.index');

    }

    public function destroy($id)
    {
        $this->commonQuestions->destroy($id);
        success_toast();
        return redirect()->back();
    }
}
