<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Repositories\CategoriesRepository;
use App\Repositories\CourseDayRepository;
use App\Repositories\CoursesRepository;
use App\Repositories\FreeCoursesRepository;
use App\Repositories\StudentsRepository;
use Illuminate\Http\Request;

class FreeCoursesController extends Controller
{
    private $coursesRepository;
    private $categoriesRepository;
    private $courseDayRepository;
     private $freeCoursesRepository;


    public function __construct(CoursesRepository $coursesRepository, CategoriesRepository $categoriesRepository, CourseDayRepository $courseDayRepository, FreeCoursesRepository $freeCoursesRepository)
    {
        $this->coursesRepository = $coursesRepository;
        $this->categoriesRepository = $categoriesRepository;
        $this->courseDayRepository = $courseDayRepository;
         $this->freeCoursesRepository = $freeCoursesRepository;
    }

    public function index()
    {
        $rows = $this->freeCoursesRepository->index();

        return view('admin.free_courses.index', compact('rows'));
    }


    public function create()
    {
        $categories = $this->categoriesRepository->index();
        $days = ['Saturday' => 'السبت', 'Sunday' => 'الأحد', 'Monday' => 'الإثنين', 'Tuesday' => 'الثلاثاء', 'Wednesday' => 'الأربعاء', 'Thursday' => 'الخميس', 'Friday' => 'الجمعة'];
        return view('admin.free_courses.create', compact('categories', 'days'));
    }

    public function getTimeDive(Request $request)
    {
        $days = ['Saturday' => 'السبت', 'Sunday' => 'الأحد', 'Monday' => 'الإثنين', 'Tuesday' => 'الثلاثاء', 'Wednesday' => 'الأربعاء', 'Thursday' => 'الخميس', 'Friday' => 'الجمعة'];

        $time_div = view('admin.free_courses.times', compact('days'))->render();
        return response()->json(['value' => true, 'time_div' => $time_div]);
    }

    public function store(Request $request)
    {
        $this->validate($request, [
            'title_ar' => 'required',
            'title_en' => 'required',
            'description_ar' => 'required',
            'description_en' => 'required',
            'category_id' => 'required',
            'start_date' => 'required',
            'end_date' => 'required|after:start_date',
            'image' => 'required|image',
            'day_name' => 'required',
            'from_hour' => 'required',
            'to_hour' => 'required',
        ]);
        $this->freeCoursesRepository->store();

        success_toast();
        return redirect()->route('free_courses.index');

    }


    public function edit($id)
    {
        $categories = $this->categoriesRepository->index();
        $days = ['Saturday' => 'السبت', 'Sunday' => 'الأحد', 'Monday' => 'الإثنين', 'Tuesday' => 'الثلاثاء', 'Wednesday' => 'الأربعاء', 'Thursday' => 'الخميس', 'Friday' => 'الجمعة'];
        $row = $this->coursesRepository->show($id);

        $course_days = $this->courseDayRepository->index($id);
        return view('admin.free_courses.edit', compact('categories', 'row', 'days', 'course_days'));
    }


    public function update(Request $request, $id)
    {
        $this->validate($request, [
            'title_ar' => 'required',
            'title_en' => 'required',
            'description_ar' => 'required',
            'description_en' => 'required',
            'category_id' => 'required',
            'start_date' => 'required',
            'end_date' => 'required|after:start_date',
            'image' => 'image',


        ]);
        $this->freeCoursesRepository->update($id);

        success_toast();
        return redirect()->route('free_courses.index');
    }

    public function show($id)
    {
        $row = $this->coursesRepository->show($id);
        $students = $this->coursesRepository->students($id);
        $documents = $this->coursesRepository->documents($id);


        return view('admin.free_courses.show', compact('row', 'students', 'documents'));
    }


}
