<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Repositories\CategoriesRepository;
use App\Repositories\ReferenceSummariesRepositories;
use Illuminate\Http\Request;

class ReferenceSummariesController extends Controller
{

    /**
     * @var ReferenceSummariesRepositories
     */
    private $referenceSummaries;
    /**
     * @var CategoriesRepository
     */
    private $categories;

    public function __construct(ReferenceSummariesRepositories $referenceSummaries, CategoriesRepository $categories)
    {
        $this->referenceSummaries = $referenceSummaries;
        $this->categories = $categories;
    }

    public function index()
    {
        $rows = $this->referenceSummaries->index();
        return view('admin.reference_summaries.index', compact('rows'));
    }


    public function create()
    {
        $categories = $this->categories->index();
        return view('admin.reference_summaries.create', compact('categories'));
    }

    public function store(Request $request)
    {
        $this->validate($request, [
            'title_ar' => 'required',
            'title_en' => 'required',
            'category_id' => 'required|exists:categories,id',
            'image' => 'required|image',
            'description_ar' => 'required',
            'description_en' => 'required',
            'inside_advise_ar' => 'required',
            'inside_advise_en' => 'required',

        ]);
        $this->referenceSummaries->store();

        success_toast();
        return redirect()->route('reference_summaries.index');

    }


    public function show($id)
    {
        //
    }

    public function edit($id)
    {
        $categories = $this->categories->index();
        $row = $this->referenceSummaries->show($id);
        return view('admin.reference_summaries.edit', compact('row', 'categories'));
    }


    public function update(Request $request, $id)
    {
        $this->validate($request, [
            'title_ar' => 'required',
            'title_en' => 'required',
            'category_id' => 'required|exists:categories,id',
//            'image' => 'required|image',
            'description_ar' => 'required',
            'description_en' => 'required',
            'inside_advise_ar' => 'required',
            'inside_advise_en' => 'required',

        ]);
        $this->referenceSummaries->update($id);

        success_toast();
        return redirect()->route('reference_summaries.index');

    }


    public function destroy($id)
    {

        $this->referenceSummaries->destroy($id);
        success_toast();
        return redirect()->back();
    }

}
