<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\RevisionPrice;
use App\Repositories\RevisionPricesRepository;
use Illuminate\Http\Request;

class RevisionPricesController extends Controller
{


    private $pricesRepository;

    public function __construct(RevisionPricesRepository $pricesRepository)
    {
        $this->pricesRepository = $pricesRepository;
    }

    public function index()
    {
        $rows = $this->pricesRepository->index();
        return view('admin.revision_prices.index', compact('rows'));
    }

    public function create()
    {
        return view('admin.revision_prices.create');
    }

    public function store(Request $request)
    {

        $this->validate($request, [
            'time_ar' => 'required',
            'time_en' => 'required',
            'price' => 'required',
            'days_count' => 'required'
        ]);
        $this->pricesRepository->store();
        success_toast();
        return redirect()->route('revision_prices.index');
    }

    public function edit($id)
    {
        $row = $this->pricesRepository->show($id);
        return view('admin.revision_prices.edit', compact('row'));
    }

    public function update(Request $request, $id)
    {
        $this->validate($request, [
            'time_ar' => 'required',
            'time_en' => 'required',
            'price' => 'required',
            'days_count' => 'required'
        ]);
        $this->pricesRepository->update($id);
        success_toast();
        return redirect()->route('revision_prices.index');
    }

    public function destroy($id)
    {
        $this->pricesRepository->destroy($id);
        success_toast();
        return redirect()->route('revision_prices.index');
    }

}
