<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Repositories\TopicLibraryRepository;
use Illuminate\Http\Request;

class TopicLibrariesController extends Controller
{


    private $libraryRepository;

    public function __construct(TopicLibraryRepository $libraryRepository)
    {
        $this->libraryRepository = $libraryRepository;
    }

    public function index()
    {
        $rows = $this->libraryRepository->index();
        return view('admin.topic_libraries.index', compact('rows'));
    }

    public function create()
    {
        return view('admin.topic_libraries.create');
    }

    public function store(Request $request)
    {
        $this->validate($request, [
            'title_ar' => 'required',
            'title_en' => 'required',
            'link' => 'required',
            'image' => 'required|image',
            'paid' => 'required',
            'price' => 'required_if:paid,paid'

        ]);


        $this->libraryRepository->store();
        success_toast();
        return redirect()->route('topic_libraries.index');
    }

    public function edit($id)
    {
        $row = $this->libraryRepository->show($id);
        return view('admin.topic_libraries.edit', compact('row'));
    }

    public function update($id, Request $request)
    {
        $this->validate($request, [
            'title_ar' => 'required',
            'title_en' => 'required',
            'link' => 'required',
            'image' => 'image',
            'paid' => 'required',
            'price' => 'required_if:paid,paid'
        ]);

        $this->libraryRepository->update($id);
        success_toast();
        return redirect()->route('topic_libraries.index');
    }

    public function destroy($id)
    {
        $this->libraryRepository->destroy($id);
        success_toast();
        return redirect()->route('topic_libraries.index');
    }

    public function show($id)
    {
        $topic = $this->libraryRepository->show($id);
        $topic_requests = $topic->subscribeRequests;
        return view('admin.topic_libraries.show', compact('topic', 'topic_requests'));
    }

    public function delete_topic_libraries_request($request_id)
    {
        $this->libraryRepository->destroy_request($request_id);
        success_toast();
        return redirect()->back();
    }

    public function edit_topic_request($request_id)
    {

        $row = $this->libraryRepository->show_topic_request($request_id);
        return view('admin.topic_libraries.edit_request', compact('row'));
    }

    public function update_topic_request(Request $request, $request_id)
    {
        $this->libraryRepository->update_topic_request($request_id);
        success_toast();
        return redirect()->back();
    }

}
