<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Category;
use App\Models\Country;
use App\Models\Token;
use App\Models\User;
use App\Repositories\CategoriesRepository;
use App\Repositories\CountriesRepository;
use App\Repositories\StudentsRepository;
use Edujugon\PushNotification\PushNotification;
use Illuminate\Http\Request;


class UsersController extends Controller
{
    private $studentsRepository;
    private $categoriesRepository;
    private $countriesRepository;

    public function __construct(StudentsRepository $studentsRepository,CategoriesRepository $categoriesRepository,CountriesRepository $countriesRepository)
    {
        $this->studentsRepository = $studentsRepository;
        $this->categoriesRepository = $categoriesRepository;
        $this->countriesRepository = $countriesRepository;
    }


    public function index()
    {
        $rows = $this->studentsRepository->index();
        return view('admin.users.index', compact('rows'));
    }


    public function edit($id)
    {
        $row = $this->studentsRepository->show($id);
        $categories = $this->categoriesRepository->index();
        $countries = $this->countriesRepository->index();
        return view('admin.users.edit', compact('row','categories','countries'));
    }

    public function update(Request $request, $id)
    {
        $this->validate($request, [
            'username' => 'required',
            'email' => 'required|email|unique:users,email,' . $id,
            'status' => 'required|in:active,not_active',
            'mobile' => 'required|unique:users,mobile,' . $id,
            'country_id' => 'required|exists:countries,id',
            'category_id' => 'required|exists:categories,id',
            'image' => 'image'
        ]);
        $this->studentsRepository->update($id);
        success_toast();
        return redirect()->route('users.index');
    }


    public function destroy($id)
    {
        $this->studentsRepository->destroy($id);
        success_toast();
        return back();
    }


}
