<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Http\Resources\CourseResource;
use App\Models\Course;
use App\Models\CourseRequest;
use App\Models\PaymentTransfer;
use App\Models\Rate;
use App\Models\UserCourse;
use Illuminate\Http\Request;
use JWTAuth;

class CoursesController extends Controller
{

    public function courses(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $rows = Course::latest()->paginate(10);
        return CourseResource::collection($rows)->additional(['value' => true,'code'=>200]);
    }

    public function single_course(Request $request, $id)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $row = Course::find($id);
        return response()->json(['data' => new CourseResource($row), 'value' => true,'code'=>200]);
    }

    public function search_courses(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);

        $validator = \Validator::make($request->all(), [
            'search' => 'required'
        ]);
        if ($validator->passes()) {

            $rows = Course::where('title->' . \App::getLocale(), 'LIKE', "%{$request->search}%")->get();

            return CourseResource::collection($rows)->additional(['value' => true,'code'=>200]);
        }
        return response()->json(['value' => false, 'msg' => $validator->errors()->first(), 'code' => 422]);

    }

    public function rate_course(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);

        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }

        $validator = \Validator::make($request->all(), [
            'course_id' => 'required|exists:courses,id',
            'course_rate' => 'required',
            'teacher_rate' => 'required',
            'description' => 'required'
        ]);
        if ($validator->passes()) {

            $rate = new Rate();
            $rate->user_id = $user->id;
            $rate->course_id = $request->course_id;
            $rate->course_rate = $request->course_rate;
            $rate->teacher_rate = $request->teacher_rate;
            $rate->description = $request->description;
            $rate->save();

            return response()->json(['value' => true, 'data' => \Lang::get('data.evaluationDoneSuccessfully'),'code'=>200]);
        }
        return response()->json(['value' => false, 'msg' => $validator->errors()->first(), 'code' => 422]);

    }


    public function course_request_free(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);

        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }

        $validator = \Validator::make($request->all(), [
            'course_id' => 'required|exists:courses,id'
        ]);
        if ($validator->passes()) {

            $course_request = new CourseRequest();
            $course_request->user_id = $user->id;
            $course_request->course_id = $request->course_id;
            $course_request->paid = 'free';
            $course_request->admin_accept = 'pending';
            $course_request->save();
            return response()->json(['value' => true, 'data' => \Lang::get('data.yourRequestHasBeenSentToManagement'),'code'=>200]);


        }
        return response()->json(['value' => false, 'msg' => $validator->errors()->first(), 'code' => 422]);

    }


    public function course_request_paid(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);

        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }

        $validator = \Validator::make($request->all(), [
            'course_id' => 'required|exists:courses,id',
            'payment_type' => 'required|in:visa,bank,paypal,zbony,sala',
            'price' => 'required',
            'image' => 'required_if:payment_type,bank|image',
            'bank_id' => 'required_if:payment_type,bank|exists:banks,id',
            'user_bank_name' => 'required_if:payment_type,bank',
            'user_account_number' => 'required_if:payment_type,bank',
            'user_iban_number' => 'required_if:payment_type,bank'
        ]);
        if ($validator->passes()) {

            $course_request = new CourseRequest();
            $course_request->user_id = $user->id;
            $course_request->course_id = $request->course_id;
            $course_request->payment_type = $request->payment_type;
            $course_request->paid = 'paid';
            $course_request->admin_accept = 'pending';
            $course_request->price = $request->price;

            $course_request->save();


            if ($course_request->payment_type == 'visa' || $course_request->payment_type == 'paypal') {

                $course_request->admin_accept = 'accepted';
                $course_request->update();

                $user_courses = new UserCourse();
                $user_courses->user_id = $user->id;
                $user_courses->course_id = $request->course_id;
                $user_courses->course_request_id = $course_request->id;
                $user_courses->save();

                return response()->json(['value' => true, 'data' => \Lang::get('data.successfullySubscribedToTheCourse'),'code'=>200]);

            } elseif ($course_request->payment_type == 'bank') {
                $payment_transfer = new PaymentTransfer();
                $payment_transfer->user_id = $user->id;
                $payment_transfer->course_id = $request->course_id;
                $payment_transfer->course_request_id = $course_request->id;
                $payment_transfer->bank_id = $request->bank_id;
                $payment_transfer->bank_id = $request->bank_id;
                $payment_transfer->user_bank_name = $request->user_bank_name;
                $payment_transfer->user_account_number = $request->user_account_number;
                if ($request->hasFile('image')) {
                    $payment_transfer->setImageAttribute();
                }
                $payment_transfer->save();
            }
            return response()->json(['value' => true, 'data' => \Lang::get('data.yourRequestHasBeenSentToManagement'),'code'=>200]);

        }
        return response()->json(['value' => false, 'msg' => $validator->errors()->first(), 'code' => 422]);

    }

}
