<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Http\Resources\BanksResource;
use App\Http\Resources\CategoriesResource;
use App\Http\Resources\CountriesResource;
use App\Http\Resources\ExamResource;
use App\Http\Resources\NewTopicesResource;
use App\Http\Resources\ReferenceSummaryResources;
use App\Http\Resources\StudentOpinionsResource;
use App\Models\Bank;
use App\Models\Category;
use App\Models\Contact;
use App\Models\Country;
use App\Models\Exam;
use App\Models\NewTopic;
use App\Models\ReferenceSummary;
use App\Models\Setting;
use App\Models\StudentOpinion;
use Illuminate\Http\Request;

class DataController extends Controller
{
    public function countries()
    {
        $rows = Country::all();
        return CountriesResource::collection($rows)->additional([
            'value' => true, 'code' => 200
        ]);
    }

    public function categories()
    {
        $rows = Category::all();
        return CategoriesResource::collection($rows)->additional([
            'value' => true, 'code' => 200
        ]);
    }

    public function settings(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $setting = Setting::first();
        $data['snapchat'] = ($setting && $setting->snapchat) ? $setting->snapchat : '';
        $data['twitter'] = ($setting && $setting->twitter) ? $setting->twitter : '';
        $data['whatsapp'] = ($setting && $setting->whatsapp) ? $setting->whatsapp : '';
        $data['instagram'] = ($setting && $setting->instagram) ? $setting->instagram : '';
        $data['zbony_link'] = ($setting && $setting->zbony_link) ? $setting->zbony_link : '';
        $data['sala_link'] = ($setting && $setting->sala_link) ? $setting->sala_link : '';
        $data['about_us'] = ($setting && $setting->about_us) ? $setting->about_us[$lang] : '';
        return response()->json(['value' => true, 'data' => $data, 'code' => 200]);
    }

    public function students_opinions(Request $request)
    {

        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);

        $rows = StudentOpinion::orderByDesc('id')->paginate(10);
        return StudentOpinionsResource::collection($rows)->additional([
            'value' => true, 'code' => 200
        ]);
    }

    public function reference_summaries(Request $request)
    {

        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);

        $rows = ReferenceSummary::paginate(10);
        return ReferenceSummaryResources::collection($rows)->additional([
            'value' => true, 'code' => 200
        ]);

    }

    public function banks(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $rows = Bank::latest()->get();
        return BanksResource::collection($rows)->additional(['value' => true, 'code' => 200]);
    }

    public function new_topics(Request $request)
    {

        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);

        $rows = NewTopic::paginate(10);
        return NewTopicesResource::collection($rows)->additional([
            'value' => true, 'code' => 200
        ]);

    }

    public function exams(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $rows = Exam::paginate(10);
        return ExamResource::collection($rows)->additional([
            'value' => true, 'code' => 200
        ]);
    }

    public function contact_us(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $validator = \Validator::make($request->all(), [
            'name' => 'required',
            'mobile' => 'required',
            'email' => 'required',
            'message' => 'required'
        ]);
        if ($validator->passes()) {
            Contact::create($request->all());
            return response()->json(['value' => true, 'data' => \Lang::get('data.saved'),'code'=>200]);
        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first(),'code'=>422]);
        }
    }
}
