<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Http\Resources\TopicLibraryResource;
use App\Models\Notification;
use App\Models\Token;
use App\Models\TopicLibrary;
use App\Models\TopicLibraryRequest;
use App\Models\UserTopic;
use Edujugon\PushNotification\PushNotification;
use Illuminate\Http\Request;
use JWTAuth;


class TopicLibrariesController extends Controller
{
    public function topic_libraries(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);

        $rows = TopicLibrary::latest()->paginate(10);
        return TopicLibraryResource::collection($rows)->additional(['value' => true,'code'=>200]);
    }

    public function topic_library_paid_requests(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);

        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }

        $validator = \Validator::make($request->all(), [
            'topic_library_id' => 'required|exists:topic_libraries,id',
            'payment_type' => 'required|in:visa,bank,paypal,zbony,sala',
            'price' => 'required',
            'image' => 'required_if:payment_type,bank|image',
            'bank_id' => 'required_if:payment_type,bank|exists:banks,id',
            'bank_name' => 'required_if:payment_type,bank',
            'bank_account_number' => 'required_if:payment_type,bank',
            'bank_iban_number' => 'required_if:payment_type,bank'
        ]);
        if ($validator->passes()) {

            $library = new TopicLibraryRequest();
            $library->user_id = $user->id;
            $library->topic_library_id = $request->topic_library_id;
            $library->price = $request->price;
            $library->payment_type = $request->payment_type;
            $library->bank_id = $request->bank_id;
            $library->bank_name = $request->bank_name;
            $library->bank_account_number = $request->bank_account_number;
            $library->bank_iban_number = $request->bank_iban_number;
            $library->admin_accept = 'pending';


            if ($request->hasFile('image')) {
                $library->setImageAttribute();
            }

            $library->save();
            if ($library->payment_type == 'visa' || $library->payment_type == 'paypal') {


                $notification = new Notification();
                $notification['body->ar'] = 'رابط فديو ' . $library->topic_library->title['ar'] . ' ' . $library->topic_library->link;
                $notification['body->en'] = 'video link ' . $library->topic_library->title['en'] . ' ' . $library->topic_library->link;
                $notification['type'] = 'download';
                $notification['user_id'] = $user->id;
                $notification['side_col'] = $library->topic_library->link;
                $notification->save();

                $tokens = Token::where('user_id', $user->id)->get();
                foreach ($tokens as $token) {

                    $push = new PushNotification('fcm');
                    if ($token->device_type == 'ios') {

                        $msg = [
                            'data' => [
                                'title' => $notification->body[$token->device_lang],
                                'sound' => 'default',
                                'click_action' => 'FCM_PLUGIN_ACTIVITY',
                                'body' => $notification->body[$token->device_lang],
                                'status' => 'download',
                                'link' => $notification->side_col

                            ],
                            'notification' => [
                                'title' => $notification->body[$token->device_lang],
                                'body' => $notification->body[$token->device_lang],
                            ],
                            'priority' => 'high',
                        ];
                        $push->setMessage($msg)
                            ->setDevicesToken($token->token)
                            ->send();
                    } else {
                        $msg = [
                            'data' => [
                                'title' => $notification->body[$token->device_lang],
                                'sound' => 'default',
                                'click_action' => 'FCM_PLUGIN_ACTIVITY',
                                'body' => $notification->body[$token->device_lang],
                                'status' => 'download',
                                'link' => $notification->side_col


                            ],
                            'priority' => 'high',
                        ];
                        $push->setMessage($msg)
                            ->setDevicesToken($token->token)
                            ->send();
                    }
                }


                return response()->json(['value' => true, 'data' => \Lang::get('data.link_confirmation_paid'),'code'=>200]);
            }
            return response()->json(['value' => true, 'data' => \Lang::get('data.link_confirmation'),'code'=>200]);

        }
        return response()->json(['value' => false, 'msg' => $validator->errors()->first(), 'code' => 422]);
    }

    public function topic_library_free_requests(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);

        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }

        $validator = \Validator::make($request->all(), [
            'topic_library_id' => 'required|exists:topic_libraries,id'
        ]);
        if ($validator->passes()) {

            $User_topic = new UserTopic();
            $User_topic->user_id = $user->id;
            $User_topic->topic_library_id = $request->topic_library_id;
            $User_topic->save();

            return response()->json(['value' => true, 'data' => \Lang::get('data.download_done'),'code'=>200]);

        }
        return response()->json(['value' => false, 'msg' => $validator->errors()->first(), 'code' => 422]);
    }
}
