<?php

namespace App\Http\Resources;

use App\Models\CourseDay;
use App\Models\CourseRequest;
use App\Models\UserCourse;
use Illuminate\Http\Resources\Json\JsonResource;
use JWTAuth;

class CourseResource extends JsonResource
{


    public function toArray($request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $subscription = 'false';
        if ($request->header('Authorization')) {

            if (!$user = JWTAuth::parseToken()->authenticate()) {
                return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
            }

            $check = UserCourse::whereUserId($user->id)->whereCourseId($this->id)->first();
            if ($check) {
                $subscription = 'true';
            } else {
                $subscription = 'false';
            }

            $status = CourseRequest::where(['course_id' => $this->id, 'user_id' => $user->id])->first();

        }




        return [
            'id' => $this->id,
            'title' => $this->title[$lang],
            'category_id' => $this->category_id,
            'category_name' => $this->category->name[$lang],
            'description' => $this->description[$lang],
            'paid' => $this->paid,
            'price' => $this->price ? $this->price : "",
            'start_date' => $this->start_date,
            'end_date' => $this->end_date,
            'course_code' => $this->course_code,
            'subscription' => $subscription,
            'status' => isset($status) ? $status->admin_accept : "",
            'zoom_link' => $this->zoom_link ? $this->zoon_link : '',
            'image' => $this->image,
            'course_rate' => getRate($this->id, 'course'),
            'teacher_rate' => getRate($this->id, 'teacher'),
            'days' => DayResource::collection($this->days()->get()),
            'documents' => DocumentResource::collection($this->documents()->get())
        ];
    }
}
