<?php


namespace App\Repositories;


use App\Models\Course;
use App\Models\CourseDay;
use App\Models\CourseDocument;
use App\Repositories\NotificationsRepository;

use Carbon\Carbon;


class CoursesRepository
{
    public function index()
    {

        return Course::wherePaid('true')->orderByDesc('id')->get();
    }

    public function store()
    {
        $course = new Course();
        $course['title->ar'] = request()->title_ar;
        $course['title->en'] = request()->title_en;
        $course['description->ar'] = request()->description_ar;
        $course['description->en'] = request()->description_en;
        $course['category_id'] = request()->category_id;
        $course['price'] = request()->price;
        $course['paid'] = 'true';
        $course['start_date'] = Carbon::parse(request()->start_date);
        $course['end_date'] = Carbon::parse(request()->end_date);
        if (request()->hasFile('image')) $course->setImageAttribute();
        $course['course_code'] = rand(1111, 9999);
        $course->save();
        $days = ['Saturday' => 'السبت', 'Sunday' => 'الأحد', 'Monday' => 'الإثنين', 'Tuesday' => 'الثلاثاء', 'Wednesday' => 'الأربعاء', 'Thursday' => 'الخميس', 'Friday' => 'الجمعة'];

        $day_name = count(request()->day_name);
        for ($i = 0; $i < $day_name; $i++) {
            $course_day = new CourseDay();
            $course_day['day_name->ar'] = $days[request()->day_name[$i]];
            $course_day['day_name->en'] = request()->day_name[$i];
            $course_day['course_id'] = $course->id;
            $course_day['day_code'] = request()->day_name[$i];
            $course_day['from_hour'] = request()->from_hour[$i];
            $course_day['to_hour'] = request()->to_hour[$i];
            $course_day->save();

        }
    }

    public function show($id)
    {
        return Course::findOrFail($id);
    }

    public function destroy($id)
    {
        Course::destroy($id);
    }

    public function update($id)
    {
        $course = $this->show($id);
        $course['title->ar'] = request()->title_ar;
        $course['title->en'] = request()->title_en;
        $course['description->ar'] = request()->description_ar;
        $course['description->en'] = request()->description_en;
        $course['category_id'] = request()->category_id;
        $course['price'] = request()->price;
        $course['start_date'] = Carbon::parse(request()->start_date);
        $course['end_date'] = Carbon::parse(request()->end_date);
        if (request()->hasFile('image')) $course->setImageAttribute();
        $course->update();
    }

    public function students($id)
    {
        $course = $this->show($id);
        return $course->students;
    }

    public function documents($id)
    {
        $course = $this->show($id);
        return $course->documents()->orderByDesc('id')->get();
    }

    public function update_course_zoom($id)
    {
        $course = $this->show($id);
        $course->zoom_link = request()->zoom_link;
        $course->update();
        // SEND NOTIFICATION
        $notification = new NotificationsRepository();
        $notification->sendZoomNotifications($this->students($id), $course);
    }

    public function attach_pdf($id)
    {
        $course = $this->show($id);
        $pdf = new CourseDocument();
        $pdf->course_id = $course->id;
        $pdf['document_name->ar'] = request()->document_name_ar;
        $pdf['document_name->en'] = request()->document_name_en;
        if (request()->hasFile('document')) $pdf->setDocumentAttribute();
        $pdf->save();
        // SEND NOTIFICATION
        $notification = new NotificationsRepository();
        $notification->sendDocumentNotifications($this->students($id), $course);
    }
    public function delete_pdf($pdf_id){
        CourseDocument::destroy($pdf_id);
    }
    public function update_pdf($pdf_id){
        $pdf = CourseDocument::findOrFail($pdf_id);
        $pdf['document_name->ar'] = request()->document_name_ar;
        $pdf['document_name->en'] = request()->document_name_en;
        if (request()->hasFile('document')) $pdf->setDocumentAttribute();
        $pdf->update();

        $notification = new NotificationsRepository();

        $course = $this->show($pdf_id);
        $notification->sendUpdatedDocumentNotifications($this->students($pdf->course_id), $course);


    }
}
